window.Gleam.initSearch([{"doc":"gleewhois","title":"gleewhois","content":"# gleewhois\r\n\r\n[![Package Version](https://img.shields.io/hexpm/v/gleewhois)](https://hex.pm/packages/gleewhois)\r\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleewhois/)\r\n\r\nWHOIS client for Gleam built using [mug🍺](https://github.com/lpil/mug). Programmatically query WHOIS servers from Gleam or use it from the command line, if for whatever reason you desire that.\r\n\r\n## Use it to query from the CLI\r\n\r\n```sh\r\n~/gleewhois$ gleam run -- --server=whois.ripe.net --port=43 AS51019\r\n```\r\n\r\n## Or use it in your code\r\n\r\n```sh\r\ngleam add gleewhois\r\n```\r\n\r\n```gleam\r\nimport gleam/io\r\nimport gleewhois.{ParsingError, SocketError, UnknownError}\r\n\r\npub fn main() {\r\n  let query =\r\n    gleewhois.query(\r\n      &quot;AS51019&quot;,\r\n      server: &quot;whois.ripe.net&quot;,\r\n      port: 43,\r\n      timeout_ms: 60_000,\r\n    )\r\n  // -&gt; Result(String, Err)\r\n\r\n  case query {\r\n    Ok(result) -&gt; io.print(result)\r\n    Error(err) -&gt;\r\n      case err {\r\n        SocketError -&gt; io.println(&quot;Error establishing connection.&quot;)\r\n        ParsingError -&gt; io.println(&quot;Error parsing result data.&quot;)\r\n        UnknownError -&gt; io.println(&quot;An unknown error ocurred during query.&quot;)\r\n      }\r\n  }\r\n}\r\n```\r\n\r\nDocumentation also available at &lt;https://hexdocs.pm/gleewhois&gt;.\r\n\r\n## License\r\n\r\nMIT\r\n","url":"index.html"},{"doc":"gleewhois","title":"Err","content":"pub type Err {\n  SocketError\n  ParsingError\n  UnknownError\n}\n Error types returned from `query`.\nSocketError\n\n\nParsingError\n\n\nUnknownError\n\n\nSynonyms:\ngleewhois.Err\ngleewhois Err","url":"gleewhois.html#Err"},{"doc":"gleewhois","title":"main","content":"pub fn main() -&gt; Nil\n Entrypoint for running CLI program.\nSynonyms:\ngleewhois.main\ngleewhois main","url":"gleewhois.html#main"},{"doc":"gleewhois","title":"query","content":"pub fn query(\n  query: String,\n  server server: String,\n  port port: Int,\n  timeout_ms timeout_ms: Int,\n) -&gt; Result(String, Err)\n Query a WHOIS server, e.g.\n \n query(&quot;AS51019&quot;, server: &quot;whois.ripe.net&quot;, port: 43, timeout_ms: 60_000)\n \n \n or for a domain name:\n \n query(&quot;ospf.se&quot;, server: &quot;whois.iis.se&quot;, port: 43, timeout_ms: 60_000)\n \n \n You can find the WHOIS server for any TLD from `whois.iana.org`, you could even do it with this library:\n \n query(&quot;se&quot;, server: &quot;whois.iana.org&quot;, port: 43, timeout_ms: 60_000)\n \n and programmatically obtain the WHOIS server for any TLD, to query for any domain name.\nSynonyms:\ngleewhois.query\ngleewhois query","url":"gleewhois.html#query"},{"doc":"gleewhois","title":"gleewhois","content":" Library to query WHOIS servers from Gleam, using the `mug` Gleam TCP client.","url":"gleewhois.html"}]);